from django.conf import settings
from django.shortcuts import render
from django.utils.safestring import mark_safe

import requests


def blog_home(request):
    context = {}

    headers = {'Authorization': 'Token %s' % settings.BUTTER_CMS_TOKEN}
    response = requests.get('http://127.0.0.1:8000/posts/', headers=headers)
    recent_posts = response.json()

    context['recent_posts'] = recent_posts
    return render(request, 'blog.html', context)


def blog_post(request, slug):
    context = {}

    headers = {'Authorization': 'Token %s' % settings.BUTTER_CMS_TOKEN}
    response = requests.get('http://127.0.0.1:8000/posts/%s' % slug, headers=headers)
    post = response.json()

    context['post'] = post
    context['post']['body'] = mark_safe(context['post']['body'])
    return render(request, 'blog_post.html', context)



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst', 'r') as f:
    readme = f.read()

packages = [
    'buttercms',
    'buttercms.templates',
]

setup(name='buttercms-django',
        version='0.1',
        description='Company blogs as a service. Built for developers.',
        long_description=readme,
        url='https://www.buttercms.com',
        author='ButterCMS',
        author_email='jake@buttercms.com',
        license='MIT',
        packages=packages,
        install_requires=['requests'],
        classifiers=[
            'Development Status :: 3 - Alpha',
            'Intended Audience :: Developers',
            'Environment :: Web Environment',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Framework :: Django',
            'Topic :: Software Development :: Build Tools',
            'License :: OSI Approved :: MIT License',
        ],
        keywords='django blog service',
        include_package_data=True,
        zip_safe=False)